/**
 * 地图Header
 */
type MapHeader = {
    /**
     * 原始地图字符串
     */
    mapHeaderStr: string;
    /**
     * 地图协议版本
     */
    version: number;
    /**
     * 地图id
     */
    id: number;
    /**
     * 地图稳定状态（建图分区完成）
     */
    mapStable: boolean;
    /**
     * 地图宽度
     */
    mapWidth: number;
    /**
     * 地图高度
     */
    mapHeight: number;
    /**
     * 地图原点x坐标
     */
    originX: number;
    /**
     * 地图原点y坐标
     */
    originY: number;
    /**
     * 地图分辨率
     */
    mapResolution: number;
    /**
     * 充电桩x坐标
     */
    chargeX: number;
    /**
     * 充电桩y坐标
     */
    chargeY: number;
    /**
     * 充电桩方向 (0x03版本支持)
     */
    chargeDirection?: number;
    /**
     * 相对充电桩坐标（根据原点偏移）
     */
    chargePositionTransformed: {
        x: number;
        y: number;
    } | null;
    /**
     * 地图数据长度（lz4压缩前）
     */
    dataLengthBeforeCompress: number;
    /**
     * 地图数据长度（lz4压缩后）
     */
    dataLengthAfterCompress: number;
};
/**
 * 房间信息
 */
type RoomDecoded = {
    /**
     * 房间id
     */
    roomId: number;
    /**
     * 房间id+点类型组合的hex (00-ff)
     */
    pointHex: string;
    /**
     * 房间名称
     */
    name: string;
    /**
     * 清扫顺序
     */
    order: number;
    /**
     * 吸力
     */
    suction: number;
    /**
     * 水量
     */
    cistern: number;
    /**
     * 颜色顺序
     */
    colorOrder: number;
    /**
     * 清扫次数
     */
    sweepTimes: number;
    /**
     * 拖地次数
     */
    mopTimes: number;
    /**
     * 是否禁止清扫
     */
    sweepForbidden: boolean;
    /**
     * 是否禁止拖地
     */
    mopForbidden: boolean;
    /**
     * 是否开启y字拖
     */
    yMop: boolean;
    /**
     * 房间地板材质
     */
    floorMaterial: number;
};
/**
 * 地图数据
 */
type MapData = {
    /**
     * 房间信息集合
     */
    mapRooms: RoomDecoded[];
    /**
     * 地图点集字符串
     */
    mapPointsStr: string;
};
/**
 * 路径Header
 */
type PathHeader = {
    /**
     * 路径版本
     */
    version: number;
    /**
     * 一次完整清扫的路径图标识
     */
    pathId: number;
    /**
     * 0x00 正常路径数据上报标志位
     * 0x01 初始化路径ID从00开始标志位（路径ID从00开始的前5个包需使用高标志位上报）
     */
    initFlag: number;
    /**
     * 路径类型
     */
    type: number;
    /**
     * 路径点数量
     */
    count: number;
    /**
     * 机器人朝向
     */
    direction: number;
    /**
     * 路径数据长度（lz4压缩后）
     */
    dataLengthAfterCompress: number;
};
/**
 * 路径点类型
 */
type PathPointType = 'common' | 'charge' | 'transitions' | 'mop';
/**
 * 路径点
 */
type PathPoint = {
    /**
     * x坐标
     */
    x: number;
    /**
     * y坐标
     */
    y: number;
    /**
     * 路径点类型
     */
    type: PathPointType;
};
/**
 * 路径数据
 */
type PathData = {
    /**
     * 路径Header
     */
    pathHeader: PathHeader;
    /**
     * 路径点集
     */
    pathPoints: PathPoint[];
};
/**
 * 标准功能数据数组(byte默认为1)
 */
type DataArray = ({
    value: number;
    byte?: number;
} | number | string)[];
/**
 * 坐标点
 */
type Point = {
    x: number;
    y: number;
};
/**
 * 0x00-both_work
 *
 * 0x01-only_sweep
 *
 * 0x02-only_mop
 */
type CleanMode = number;
/**
 * 0x00-closed
 * 0x01-gentle
 * 0x02-normal
 * 0x03-strong
 * 0x04-max
 */
type Suction = number;
/**
 * 0x00-closed
 * 0x01-low
 * 0x02-middle
 * 0x03-high
 */
type Cistern = number;
/**
 * 0x00-off
 * 0x01-open
 * 0x03-high
 */
type yMop = number;
/**
 * 0x00 - 矩形
 *
 * 0x01 - 多边形
 */
type ShapeType = number;
/**
 * 0x00 - 全禁
 *
 * 0x01 - 禁扫
 *
 * 0x02 - 禁拖
 */
type ForbiddenType = number;
/**
 * 虚拟墙
 */
type VirtualWall = {
    /**
     * 虚拟墙点集
     */
    points: Point[];
    /**
     * 虚拟墙类型
     */
    mode: ForbiddenType;
};
/**
 * 禁区
 */
type VirtualArea = {
    /**
     * 禁区点集
     */
    points: Point[];
    /**
     * 禁区类型
     */
    mode: ForbiddenType;
    /**
     * 禁区名称
     */
    name?: string;
};
/**
 * 定点清扫区域
 */
type Zone = {
    /**
     * 清扫区域点集
     */
    points: Point[];
    /**
     * 清扫区域名称
     */
    name?: string;
    advanced?: {
        id: number;
        localSave: number;
        cleanMode: CleanMode;
        order: number;
        cleanTimes: number;
        suction: Suction;
        cistern: Cistern;
    };
};
type TimerData = {
    effectiveness: number;
    week: number[];
    time: {
        hour: number;
        minute: number;
    };
    roomIds: number[];
    cleanMode: number;
    fanLevel: number;
    waterLevel: number;
    sweepCount: number;
    roomNum: number;
};
type AiPicInfo = {
    id: string;
    mapId: number;
    position: {
        x: number;
        y: number;
    };
    object: number;
    accuracy: number;
    reserved: number;
    xHex: string;
    yHex: string;
};
type AIPicHD = {
    source: string;
};

/**
 * 获取Map协议的版本 对应第一个Byte
 * @param mapStr
 */
declare const getMapProtocolVersion: (mapStr: string) => number;
/**
 * 解析地图Header version: 0x00,0x01,0x02
 * @param mapStr 原始地图字符串
 * @returns 地图Header数据
 */
declare const decodeMapHeader: (mapStr: string) => MapHeader;

/**
 * 解析地图数据 version: 0x00,0x01,0x02
 * @param mapStr 原始地图字符串
 * @param mapHeader 地图Header数据
 * @returns 地图点集及房间相关数据
 */
declare const decodeMapData: (mapStr: string, mapHeader: MapHeader) => MapData;

/**
 * 解析地图数据 version: 0x00,0x01,0x02,0x03
 * @param mapStr 原始地图字符串
 * @returns 地图数据
 */
declare const decodeMap: (mapStr: string) => {
    /**
     * 地图Header
     */
    mapHeader: MapHeader;
    /**
     * 地图数据
     */
    mapData: MapData;
};

/**
 * 解析路径Header
 * @param pathStr 原始路径字符串
 * @returns 路径Header数据
 */
declare const decodePathHeader: (pathStr: string) => PathHeader;

/**
 * 解析路径点集
 * @param pathStr 原始路径字符串
 * @param pathHeader 路径Header数据
 * @returns 路径点集数据
 */
declare const decodePathData: (pathStr: string, pathHeader: PathHeader) => PathPoint[];

/**
 * 解析路径数据
 * @param pathStr 原始路径字符串
 * @returns 路径数据
 */
declare const decodePath: (pathStr: string) => PathData;

/**
 * 解码AI图片数据
 * 该函数用于解析给定字符串格式的AI图片信息，将其转换为结构化数据数组
 * @param params 包含待解析字符串和地图缩放比例的参数对象
 * @param params.str 待解析的字符串
 * @param params.mapScale 地图缩放比例，默认为1
 * @returns 返回一个结构化的AI图片信息数组
 */
declare const decodeAiPicData: (params: {
    str: string;
    mapScale?: number;
}) => AiPicInfo[];

/**
 * 解码AI高清图片数据
 * 该函数接受一个十六进制字符串作为输入，将其解码为原始的图片数据，并以Base64格式返回
 * 主要用于处理通过特定加密或压缩方式处理过的图片数据，以便在应用中正确显示图片
 *
 * @param str 十六进制编码的字符串，代表加密或压缩过的图片数据
 * @returns 返回一个包含解码后Base64格式图片数据的对象
 */
declare const decodeAiPicHDData: (str: string) => AIPicHD;

/**
 * *虚拟墙设置0x12/0x13
 *
 * 向设备请求虚拟墙数据(0x13) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const requestVirtualWall0x13: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * @deprecated 请使用 requestVirtualWall0x13
 */
declare const requestVirtualWallV1: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * *虚拟墙设置0x12/0x13
 *
 * 设置虚拟墙的指令(0x12) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeVirtualWall0x12: (params: {
    walls: Point[][];
    origin: Point;
    mapScale?: number;
    version?: '0' | '1';
}) => string;
/**
 * @deprecated 请使用 encodeVirtualWall0x12
 */
declare const encodeVirtualWallV1: (params: {
    walls: Point[][];
    origin: Point;
    mapScale?: number;
    version?: '0' | '1';
}) => string;
/**
 * *虚拟墙设置0x12/0x13
 *
 * 从指令中解析获取虚拟墙数据(0x13) | Robot ➜ App
 * @param params 参数
 * @returns 虚拟墙数据
 */
declare const decodeVirtualWall0x13: (params: {
    command: string;
    mapScale?: number;
    version?: '0' | '1';
}) => Point[][] | null;
/**
 * @deprecated 请使用 decodeVirtualWall0x13
 */
declare const decodeVirtualWallV1: (params: {
    command: string;
    mapScale?: number;
    version?: '0' | '1';
}) => Point[][] | null;

/**
 * *虚拟墙设置0x48/0x49
 *
 * 向设备请求虚拟墙数据(0x49) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const requestVirtualWall0x49: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * *虚拟墙设置0x48/0x49
 *
 * 设置虚拟墙的指令(0x48) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeVirtualWall0x48: (params: {
    protocolVersion?: number;
    walls: VirtualWall[];
    origin: Point;
    mapScale?: number;
    version?: '0' | '1';
}) => string;
/**
 * *虚拟墙设置0x48/0x49
 *
 * 从指令中解析获取虚拟墙数据(0x49) | Robot ➜ App
 * @param params 参数
 * @returns 虚拟墙数据
 */
declare const decodeVirtualWall0x49: (params: {
    command: string;
    mapScale?: number;
    version?: '0' | '1';
}) => {
    protocolVersion: number;
    walls: VirtualWall[];
};

/**
 * *选区清扫0x14/0x15
 *
 * 向设备请求选区清扫数据(0x15) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const requestRoomClean0x15: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * @deprecated 请使用 requestRoomClean0x15
 */
declare const requestRoomCleanV1: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * *选区清扫0x14/0x15
 *
 * 设置选区清扫的指令(0x14) | App ➜ Robot
 * @param params 参数 - 支持传入roomHexIds或roomIds
 * @returns 指令
 */
declare const encodeRoomClean0x14: (params: {
    cleanTimes: number;
    roomHexIds?: string[];
    roomIds?: number[];
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => string;
/**
 * @deprecated 请使用 encodeRoomClean0x14
 */
declare const encodeRoomCleanV1: (params: {
    cleanTimes: number;
    roomHexIds?: string[];
    roomIds?: number[];
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => string;
/**
 * *选区清扫0x14/0x15
 *
 * 从指令中解析获取选区清扫信息(0x15) | Robot ➜ App
 * @param params 参数
 * @returns 选区清扫信息
 */
declare const decodeRoomClean0x15: (params: {
    command: string;
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => {
    cleanTimes: number;
    roomIds: number[];
    roomHexIds: string[];
};
/**
 * @deprecated 请使用 decodeRoomClean0x15
 */
declare const decodeRoomCleanV1: (params: {
    command: string;
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => {
    cleanTimes: number;
    roomIds: number[];
    roomHexIds: string[];
};

type Room$2 = {
    roomHexId?: string;
    roomId?: number;
    cleanTimes: number;
    yMop: yMop | 'ff';
    suction: Suction | 'ff';
    cistern: Cistern | 'ff';
};
/**
 * *选区清扫0x56/0x57
 *
 * 向设备请求选区清扫数据(0x57) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const requestRoomClean0x57: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * @deprecated 请使用 requestRoomClean0x57
 */
declare const requestRoomCleanV2: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * *选区清扫0x56/0x57
 *
 * 设置选区清扫的指令(0x56) | App ➜ Robot
 * @param params 参数 - 支持传入roomHexIds或roomIds
 * @returns 指令
 */
declare const encodeRoomClean0x56: (params: {
    rooms: Room$2[];
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => string;
/**
 * @deprecated 请使用 encodeRoomClean0x56
 */
declare const encodeRoomCleanV2: (params: {
    rooms: Room$2[];
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => string;
/**
 * *选区清扫0x56/0x57
 *
 * 从指令中解析获取选区清扫信息(0x57) | Robot ➜ App
 * @param params 参数
 * @returns 选区清扫信息
 */
declare const decodeRoomClean0x57: (params: {
    command: string;
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => Room$2[] | null;
/**
 * @deprecated 请使用 decodeRoomClean0x57
 */
declare const decodeRoomCleanV2: (params: {
    command: string;
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => Room$2[] | null;

/**
 * 向设备请求房间清扫顺序数据(0x26)
 *
 * 该函数用于生成请求房间订单的标准命令字符串。
 * 它接受一个参数对象，其中可选地包含版本号，如果没有提供版本号，默认使用V1。
 *
 * @param {Object} params - 函数的参数对象。
 * @param {('0' | '1')} params.version - 请求的命令版本号，可选值为'0'或'1'，默认为'1'。
 * @returns {string} 返回编码后的标准命令字符串。
 */
declare const requestRoomOrder0x26: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * @deprecated 请使用 requestRoomOrder0x26
 */
declare const requestRoomOrderV1: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * 编码房间顺序信息。(0x26 / 0x27)
 *
 * 此函数用于将房间ID的数组编码为一个字符串，以便于传输或存储。
 * 版本号用于区分不同的编码格式。
 *
 * @param {Object} params - 函数参数对象。
 * @param {('0' | '1')[]} params.roomIdHexs - 房间ID的数组，每个房间ID是一个字符串。
 * @param {'0' | '1'} [params.version='1'] - 编码版本号，决定如何解析房间ID。
 * @returns {string} - 编码后的字符串。
 */
declare const encodeRoomOrder0x26: (params: {
    version?: '0' | '1';
    roomIdHexs: string[];
    mapVersion: 0 | 1 | 2;
}) => string;
/**
 * @deprecated 请使用 encodeRoomOrder0x26
 */
declare const encodeRoomOrderV1: (params: {
    version?: '0' | '1';
    roomIdHexs: string[];
    mapVersion: 0 | 1 | 2;
}) => string;
/**
 * 解码房间清扫顺序信息。
 *
 * 该函数用于解析特定格式的命令字符串，从中提取房间订单相关信息。
 *
 * @param {Object} params - 解码参数对象。
 * @param {string} params.command - 待解码的命令字符串。
 * @param {'0' | '1'} [params.version='1'] - 命令字符串的版本信息，默认为'1'。
 * @returns {string[] | null} - 解码后的房间订单信息数组，如果解码失败则返回null。
 */
declare const decodeRoomOrder0x27: (params: {
    command: string;
    version?: '0' | '1';
}) => number[] | null;
/**
 * @deprecated 请使用 decodeRoomOrder0x27
 */
declare const decodeRoomOrderV1: (params: {
    command: string;
    version?: '0' | '1';
}) => number[] | null;

/**
 * *定点清扫0x16/0x17
 *
 * 向设备请求定点清扫数据(0x17) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const requestSpotClean0x17: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * @deprecated 请使用 requestSpotClean0x17
 */
declare const requestSpotCleanV1: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * * *定点清扫0x16/0x17
 *
 * 设置定点清扫的指令(0x16) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeSpotClean0x16: (params: {
    point: Point;
    origin: Point;
    mapScale?: number;
    version?: '0' | '1';
}) => string;
/**
 * @deprecated 请使用 encodeSpotClean0x16
 */
declare const encodeSpotCleanV1: (params: {
    point: Point;
    origin: Point;
    mapScale?: number;
    version?: '0' | '1';
}) => string;
/**
 * *定点清扫0x16/0x17
 *
 * 从指令中解析获取定点清扫数据(0x17) | Robot ➜ App
 * @param params 参数
 * @returns 定点清扫信息
 */
declare const decodeSpotClean0x17: (params: {
    command: string;
    mapScale?: number;
    version?: '0' | '1';
}) => {
    point: Point;
} | null;
/**
 * @deprecated 请使用 decodeSpotClean0x17
 */
declare const decodeSpotCleanV1: (params: {
    command: string;
    mapScale?: number;
    version?: '0' | '1';
}) => {
    point: Point;
} | null;

/**
 * *定点清扫0x3e/0x3f
 *
 * 向设备请求定点清扫数据(0x3f) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const requestSpotClean0x3f: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * @deprecated 请使用 requestSpotClean0x3f
 */
declare const requestSpotCleanV2: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * * *定点清扫0x3e/0x3f (注意根据Protocol version不同，协议内容有区别)
 *
 * 设置定点清扫的指令(0x3e) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeSpotClean0x3e: (params: {
    protocolVersion: 1 | 2;
    points: Point[];
    origin: Point;
    cleanMode?: CleanMode;
    suction?: Suction;
    cistern?: Cistern;
    cleanTimes?: number;
    mapScale?: number;
    version?: '0' | '1';
}) => string;
/**
 * @deprecated 请使用 encodeSpotClean0x3e
 */
declare const encodeSpotCleanV2: (params: {
    protocolVersion: 1 | 2;
    points: Point[];
    origin: Point;
    cleanMode?: CleanMode;
    suction?: Suction;
    cistern?: Cistern;
    cleanTimes?: number;
    mapScale?: number;
    version?: '0' | '1';
}) => string;
/**
 * *定点清扫0x3e/0x3f (注意根据Protocol version不同，协议内容有区别)
 *
 * 从指令中解析获取定点清扫数据(0x3f) | Robot ➜ App
 * @param params 参数
 * @returns 定点清扫信息
 */
declare const decodeSpotClean0x3f: (params: {
    command: string;
    mapScale?: number;
    version?: '0' | '1';
}) => {
    protocolVersion: 1 | 2;
    points: Point[];
    cleanMode?: CleanMode;
    suction?: Suction;
    cistern?: Cistern;
    cleanTimes?: number;
};
/**
 * @deprecated 请使用 decodeSpotClean0x3f
 */
declare const decodeSpotCleanV2: (params: {
    command: string;
    mapScale?: number;
    version?: '0' | '1';
}) => {
    protocolVersion: 1 | 2;
    points: Point[];
    cleanMode?: CleanMode;
    suction?: Suction;
    cistern?: Cistern;
    cleanTimes?: number;
};

/**
 * *禁区设置0x1a/0x1b
 *
 * 向设备请求禁区数据(0x1b) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const requestVirtualArea0x1b: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * * *禁区设置0x1a/0x1b
 *
 * 设置禁区的指令(0x1a) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeVirtualArea0x1a: (params: {
    virtualAreas: VirtualArea[];
    origin: Point;
    mapScale?: number;
    version?: '0' | '1';
}) => string;
/**
 * *禁区设置0x1a/0x1b
 *
 * 从指令中解析获取禁区数据(0x1b) | Robot ➜ App
 * @param params 参数
 * @returns 禁区数据
 */
declare const decodeVirtualArea0x1b: (params: {
    command: string;
    mapScale?: number;
    version?: '0' | '1';
}) => VirtualArea[] | null;

/**
 * *禁区设置0x38/0x39
 *
 * 向设备请求禁区数据(0x39) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const requestVirtualArea0x39: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * @deprecated 请使用 requestVirtualArea0x39
 */
declare const requestVirtualAreaV2: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * * *禁区设置0x38/0x39 (注意根据Protocol version不同，协议内容有区别)
 *
 * 设置禁区的指令(0x38) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeVirtualArea0x38: (params: {
    protocolVersion: 1 | 2;
    virtualAreas: VirtualArea[];
    origin: Point;
    mapScale?: number;
    version?: '0' | '1';
}) => string;
/**
 * @deprecated 请使用 encodeVirtualArea0x38
 */
declare const encodeVirtualAreaV2: (params: {
    protocolVersion: 1 | 2;
    virtualAreas: VirtualArea[];
    origin: Point;
    mapScale?: number;
    version?: '0' | '1';
}) => string;
/**
 * *禁区设置0x38/0x39 (注意根据Protocol version不同，协议内容有区别)
 *
 * 从指令中解析获取禁区数据(0x39) | Robot ➜ App
 * @param params 参数
 * @returns 禁区数据
 */
declare const decodeVirtualArea0x39: (params: {
    command: string;
    mapScale?: number;
    version?: '0' | '1';
}) => {
    protocolVersion: 1 | 2;
    virtualAreas: VirtualArea[];
};
/**
 * @deprecated 请使用 decodeVirtualArea0x39
 */
declare const decodeVirtualAreaV2: (params: {
    command: string;
    mapScale?: number;
    version?: '0' | '1';
}) => {
    protocolVersion: 1 | 2;
    virtualAreas: VirtualArea[];
};

/**
 * *分区分割0x1c/0x1d
 *
 * 向设备下发的分区分割指令(0x1c) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodePartitionDivision0x1c: (params: {
    roomId: number;
    points: Point[];
    origin: Point;
    mapScale?: number;
    version?: '0' | '1';
}) => string;
/**
 * @deprecated 请使用 encodePartitionDivision0x1c
 */
declare const encodePartitionDivisionV1: (params: {
    roomId: number;
    points: Point[];
    origin: Point;
    mapScale?: number;
    version?: '0' | '1';
}) => string;
/**
 * *分区分割0x1c/0x1d
 *
 * 解析设备响应的分区分割结果(0x1d) | Robot ➜ App
 * @param params 参数
 * @returns 分区分割结果
 */
declare const decodePartitionDivision0x1d: (params: {
    command: string;
    mapScale?: number;
    version?: '0' | '1';
}) => {
    ret: number;
    success: boolean;
};
/**
 * @deprecated 请使用 decodePartitionDivision0x1d
 */
declare const decodePartitionDivisionV1: (params: {
    command: string;
    mapScale?: number;
    version?: '0' | '1';
}) => {
    ret: number;
    success: boolean;
};

/**
 * *分区合并0x1e/0x1f
 *
 * 向设备下发的分区合并指令(0x1e) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodePartitionMerge0x1e: (params: {
    roomIds: number[];
    version?: '0' | '1';
}) => string;
/**
 * @deprecated 请使用 encodePartitionMerge0x1e
 */
declare const encodePartitionMergeV1: (params: {
    roomIds: number[];
    version?: '0' | '1';
}) => string;
/**
 * *分区合并0x1e/0x1f
 *
 * 解析设备响应的分区合并结果(0x1f) | Robot ➜ App
 * @param params 参数
 * @returns 分区合并结果
 */
declare const decodePartitionMerge0x1f: (params: {
    command: string;
    version?: '0' | '1';
}) => {
    ret: number;
    success: boolean;
};
/**
 * @deprecated 请使用 decodePartitionMerge0x1f
 */
declare const decodePartitionMergeV1: (params: {
    command: string;
    version?: '0' | '1';
}) => {
    ret: number;
    success: boolean;
};

type Room$1 = {
    name: string;
    roomHexId?: string;
    roomId?: number;
};
/**
 * *设置房间名称0x24/0x25
 *
 * 向设备下发的设置房间名称指令(0x24) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeSetRoomName0x24: (params: {
    rooms: Room$1[];
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => string;
/**
 * @deprecated 请使用 encodeSetRoomName0x24
 */
declare const encodeSetRoomNameV1: (params: {
    rooms: Room$1[];
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => string;
/**
 * *设置房间名称0x24/0x25
 *
 * 解析设备响应的设置房间名称结果(0x25) | Robot ➜ App
 * @param params 参数
 * @returns 设置房间名称结果
 */
declare const decodeSetRoomName0x25: (params: {
    command: string;
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => Room$1[] | null;
/**
 * @deprecated 请使用 decodeSetRoomName0x25
 */
declare const decodeSetRoomNameV1: (params: {
    command: string;
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => Room$1[] | null;

type Room = {
    roomHexId?: string;
    roomId?: number;
    cleanTimes: number;
    yMop: yMop | 'ff';
    suction: Suction | 'ff';
    cistern: Cistern | 'ff';
};
/**
 * *设置房间属性0x22/0x23
 *
 * 向设备下发的设置房间属性指令(0x22) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeSetRoomProperty0x22: (params: {
    rooms: Room[];
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => string;
/**
 * @deprecated 请使用 encodeSetRoomProperty0x22
 */
declare const encodeSetRoomPropertyV1: (params: {
    rooms: Room[];
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => string;
/**
 * *设置房间属性0x22/0x23
 *
 * 解析设备响应的设置房间属性结果(0x23) | Robot ➜ App
 * @param params 参数
 * @returns 设置房间属性结果
 */
declare const decodeSetRoomProperty0x23: (params: {
    command: string;
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => Room[] | null;
/**
 * @deprecated 请使用 decodeSetRoomProperty0x23
 */
declare const decodeSetRoomPropertyV1: (params: {
    command: string;
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => Room[] | null;

/**
 * *划区清扫0x28/0x29
 *
 * 向设备请求划区清扫数据(0x29) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const requestZoneClean0x29: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * *划区清扫0x28/0x29
 *
 * 划区清扫的指令(0x28) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeZoneClean0x28: (params: {
    zones: Zone[];
    origin: Point;
    cleanTimes?: number;
    mapScale?: number;
    version?: '0' | '1';
}) => string;
/**
 * *划区清扫0x28/0x29
 *
 * 从指令中解析获取划区清扫数据(0x29) | Robot ➜ App
 * @param params 参数
 * @returns 划区清扫数据
 */
declare const decodeZoneClean0x29: (params: {
    command: string;
    mapScale?: number;
    version?: '0' | '1';
}) => {
    zones: Zone[];
    cleanTimes?: number;
};

/**
 * *划区清扫0x3a/0x3b
 *
 * 向设备请求划区清扫数据(0x3b) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const requestZoneClean0x3b: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * @deprecated 请使用 requestZoneClean0x3b
 */
declare const requestZoneCleanV2: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * *划区清扫0x3a/0x3b (注意根据Protocol version不同，协议内容有区别)
 *
 * 划区清扫的指令(0x3a) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeZoneClean0x3a: (params: {
    protocolVersion: 1 | 2 | 3;
    zones: Zone[];
    origin: Point;
    cleanMode?: CleanMode;
    suction?: Suction;
    cistern?: Cistern;
    cleanTimes?: number;
    mapScale?: number;
    version?: '0' | '1';
}) => string;
/**
 * @deprecated 请使用 encodeZoneClean0x3a
 */
declare const encodeZoneCleanV2: (params: {
    protocolVersion: 1 | 2 | 3;
    zones: Zone[];
    origin: Point;
    cleanMode?: CleanMode;
    suction?: Suction;
    cistern?: Cistern;
    cleanTimes?: number;
    mapScale?: number;
    version?: '0' | '1';
}) => string;
/**
 * *划区清扫0x3a/0x3b (注意根据Protocol version不同，协议内容有区别)
 *
 * 从指令中解析获取划区清扫数据(0x3b) | Robot ➜ App
 * @param params 参数
 * @returns 划区清扫数据
 */
declare const decodeZoneClean0x3b: (params: {
    command: string;
    mapScale?: number;
    version?: '0' | '1';
}) => {
    protocolVersion: 1 | 2 | 3;
    zones: Zone[];
    cleanMode?: CleanMode;
    suction?: Suction;
    cistern?: Cistern;
    cleanTimes?: number;
};
/**
 * @deprecated 请使用 decodeZoneClean0x3b
 */
declare const decodeZoneCleanV2: (params: {
    command: string;
    mapScale?: number;
    version?: '0' | '1';
}) => {
    protocolVersion: 1 | 2 | 3;
    zones: Zone[];
    cleanMode?: CleanMode;
    suction?: Suction;
    cistern?: Cistern;
    cleanTimes?: number;
};

/**
 * *勿扰时间设置0x32/0x33
 *
 * 设置勿扰时间的指令(0x32) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeDoNotDisturb0x32: (params: {
    startHour: number;
    startMinute: number;
    endHour: number;
    endMinute: number;
    timeZone?: number;
    version?: '0' | '1';
}) => string;
/**
 * *勿扰时间设置0x32/0x33
 *
 * 从指令中解析获取勿扰时间数据(0x33) | Robot ➜ App
 * @param params 参数
 * @returns 勿扰时间数据
 */
declare const decodeDoNotDisturb0x33: (params: {
    command: string;
    version?: '0' | '1';
}) => {
    timeZone: number;
    startHour: number;
    startMinute: number;
    endHour: number;
    endMinute: number;
};

/**
 * *勿扰时间设置0x40/0x41
 *
 * 设置勿扰时间的指令(0x40) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeDoNotDisturb0x40: (params: {
    enable: boolean;
    startHour: number;
    startMinute: number;
    endHour: number;
    endMinute: number;
    timeZone?: number;
    version?: '0' | '1';
}) => string;
/**
 * @deprecated 请使用 encodeDoNotDisturb0x40
 */
declare const encodeDoNotDisturbV2: (params: {
    enable: boolean;
    startHour: number;
    startMinute: number;
    endHour: number;
    endMinute: number;
    timeZone?: number;
    version?: '0' | '1';
}) => string;
/**
 * *勿扰时间设置0x40/0x41
 *
 * 从指令中解析获取勿扰时间数据(0x41) | Robot ➜ App
 * @param params 参数
 * @returns 勿扰时间数据
 */
declare const decodeDoNotDisturb0x41: (params: {
    command: string;
    version?: '0' | '1';
}) => {
    enable: boolean;
    timeZone: number;
    startHour: number;
    startMinute: number;
    endHour: number;
    endMinute: number;
};
/**
 * @deprecated 请使用 decodeDoNotDisturb0x41
 */
declare const decodeDoNotDisturbV2: (params: {
    command: string;
    version?: '0' | '1';
}) => {
    enable: boolean;
    timeZone: number;
    startHour: number;
    startMinute: number;
    endHour: number;
    endMinute: number;
};

/**
 * *重置当前首页地图0x42/0x43
 *
 * 向设备下发的快速建图指令(0x42) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeResetMap0x42: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * @deprecated 请使用 encodeResetMap0x42
 */
declare const encodeResetMapV1: (params?: {
    version?: '0' | '1';
}) => string;

/**
 * *快速建图0x3c/0x3d
 *
 * 向设备下发的快速建图指令(0x3c) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeQuickMap0x3c: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * @deprecated 请使用 encodeQuickMap0x3c
 */
declare const encodeQuickMapV1: (params?: {
    version?: '0' | '1';
}) => string;

declare const encodeDeviceTimer0x30: (params: {
    list: TimerData[];
    number: number;
    version?: '0' | '1';
}) => string;
/**
 * *设备定时时间设置0x40/0x41
 *
 * 从指令中解析获取本地定时数据(0x31) | Robot ➜ App
 * @param params 参数
 * @returns 勿扰时间数据
 */
declare const decodeDeviceTimer0x31: (params: {
    command: string;
    version?: '0' | '1';
}) => {
    number: number;
    timeZone: number;
    list: TimerData[];
};

type SetRoomFloorMaterial = {
    roomId: number;
    material: number;
};
/**
 * 向设备下发设置房间分区地板材质的数据(0x52) | App ➜ Robot
 * @param params
 * @returns
 */
declare const encodeSetRoomFloorMaterial0x52: (params: {
    rooms: SetRoomFloorMaterial[];
    version?: '0' | '1';
}) => string;
/**
 * 解析设备响应的设置房间分区地板材质的结果(0x53) | Robot ➜ App
 * @param params
 * @returns
 */
declare const decodeSetRoomFloorMaterial0x53: (params: {
    command: string;
    version?: '0' | '1';
}) => SetRoomFloorMaterial[];

/**
 * *保存地图0x2a/0x2b
 *
 * 保存地图指令(0x2a) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeSaveMap0x2a: (saveSpace?: number) => string;
/**
 * @deprecated 请使用 encodeSaveMap0x2a
 */
declare const encodeSaveMapV1: (saveSpace?: number) => string;
/**
 * *保存地图0x2a/0x2b
 *
 * 保存地图结果(0x2b) | Robot ➜ App
 * @param params 参数
 * @returns 保存地图结果
 */
declare const decodeSaveMap0x2b: (params: {
    command: string;
}) => {
    ret: number;
    success: boolean;
};
/**
 * @deprecated 请使用 decodeSaveMap0x2b
 */
declare const decodeSaveMapV1: (params: {
    command: string;
}) => {
    ret: number;
    success: boolean;
};

/**
 * *删除地图0x2c/0x2d
 *
 * 删除地图指令(0x2c) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeDeleteMap0x2c: (params: {
    id: number;
}) => string;
/**
 * @deprecated 请使用 encodeDeleteMap0x2c
 */
declare const encodeDeleteMapV1: (params: {
    id: number;
}) => string;
/**
 * *删除地图0x2c/0x2d
 *
 * 删除地图结果(0x2d) | Robot ➜ App
 * @param params 参数
 * @returns 删除地图结果
 */
declare const decodeDeleteMap0x2d: (params: {
    command: string;
}) => {
    ret: number;
    success: boolean;
};
/**
 * @deprecated 请使用 decodeDeleteMap0x2d
 */
declare const decodeDeleteMapV1: (params: {
    command: string;
}) => {
    ret: number;
    success: boolean;
};

/**
 * *使用地图0x2e/0x2f
 *
 * 使用地图指令(0x2e) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeUseMap0x2e: (params: {
    mapId: number;
    url: string;
}) => string;
/**
 * @deprecated 请使用 encodeUseMap0x2e
 */
declare const encodeUseMapV1: (params: {
    mapId: number;
    url: string;
}) => string;
/**
 * *使用地图0x2e/0x2f
 *
 * 使用地图结果(0x2f) | Robot ➜ App
 * @param params 参数
 * @returns 使用地图结果
 */
declare const decodeUseMap0x2f: (params: {
    command: string;
}) => {
    ret: number;
    success: boolean;
};
/**
 * @deprecated 请使用 decodeUseMap0x2f
 */
declare const decodeUseMapV1: (params: {
    command: string;
}) => {
    ret: number;
    success: boolean;
};

/**
 * *语音包0x34/0x35
 *
 * 语音包指令(0x34) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeVoice0x34: (params: {
    id: number;
    md5: string;
    url: string;
}) => string;
/**
 * *语音包0x34/0x35
 *
 * 语音包状态上报(0x35) | Robot ➜ App
 * @param params 参数
 * @returns 语音包状态
 */
declare const decodeVoice0x35: (params: {
    command: string;
}) => {
    languageId: number;
    status: number;
    progress: number;
};

declare const POINT_HEX_TOTAL = 255;
declare const ROOM_PROPERTY_LENGTH = 26;
declare const ROOM_NAME_LENGTH = 20;
declare const ROOM_VERTICES_NUM_LENGTH = 1;
/**
 * 默认标准高亮色
 */
declare const DEFAULT_HIGHLIGHT_MAP_COLOR: string[];
/**
 * 默认标准灰色
 */
declare const DEFAULT_NORMAL_MAP_COLOR: string[];
/**
 * 地图数据对应的类型点(十六进制)
 * 普通版本(version:00)
 */
declare const BITMAP_TYPE_HEX_MAP: {
    readonly '00': "00";
    readonly '01': "f1";
    readonly '10': "f2";
    readonly '11': "ff";
};
/**
 * 地图数据对应的类型点
 * 普通版本/分区版本(version:00/01)
 */
declare const BITMAP_TYPE_MAP: {
    readonly sweep: "00";
    readonly barrier: "01";
    readonly battery: "10";
    readonly unknown: "11";
};
/**
 * 地图数据对应的类型点
 * 地毯版本(version:02)
 */
declare const BITMAP_TYPE_MAP_V2: {
    readonly sweep: "111";
    readonly barrier: "001";
    readonly carpet: "010";
    readonly unknown: "000";
};
/**
 * 地图数据点对应的类型
 */
declare const BITMAP_TYPE_MAP_REFLECTION: {
    readonly '00': "sweep";
    readonly '01': "barrier";
    readonly '10': "battery";
    readonly '11': "unknown";
    readonly '111': "sweep";
    readonly '001': "barrier";
    readonly '000': "unknown";
    readonly '010': "carpet";
};
declare const UNKNOWN_AREA_ID: number[];
declare const UNKNOWN_AREA_ID_V2: number[];

declare const PATH_HEADER_LENGTH = 13;
declare const PATH_POINT_TYPE_MAP: Record<string, PathPointType>;

/**
 * 标准功能帧头
 */
declare const STANDARD_FEATURE_HEADER = "aa";
/**
 * 虚拟墙设置V1 App ➜ Robot
 */
declare const VIRTUAL_WALL_CMD_APP_V1 = "12";
/**
 * 虚拟墙设置V1 Robot ➜ App
 */
declare const VIRTUAL_WALL_CMD_ROBOT_V1 = "13";
/**
 * 虚拟墙设置V2 App ➜ Robot
 */
declare const VIRTUAL_WALL_CMD_APP_V2 = "48";
/**
 * 虚拟墙设置V2 Robot ➜ App
 */
declare const VIRTUAL_WALL_CMD_ROBOT_V2 = "49";
/**
 * 禁区设置V1 App ➜ Robot
 */
declare const VIRTUAL_AREA_CMD_APP_V1 = "1a";
/**
 * 禁区设置V1 Robot ➜ App
 */
declare const VIRTUAL_AREA_CMD_ROBOT_V1 = "1b";
/**
 * 禁区设置V2 App ➜ Robot
 */
declare const VIRTUAL_AREA_CMD_APP_V2 = "38";
/**
 * 禁区设置V2 Robot ➜ App
 */
declare const VIRTUAL_AREA_CMD_ROBOT_V2 = "39";
/**
 * 选区清扫V1 App ➜ Robot
 */
declare const ROOM_CLEAN_CMD_APP_V1 = "14";
/**
 * 选区清扫V1 Robot ➜ App
 */
declare const ROOM_CLEAN_CMD_ROBOT_V1 = "15";
/**
 * 选区清扫V2 App ➜ Robot
 */
declare const ROOM_CLEAN_CMD_APP_V2 = "56";
/**
 * 选区清扫V2 Robot ➜ App
 */
declare const ROOM_CLEAN_CMD_ROBOT_V2 = "57";
/**
 * 设置清扫顺序V1  App ➜ Robot
 */
declare const ROOM_ORDER_CMD_APP_V1 = "26";
/**
 * 设置清扫顺序V1  Robot ➜ App
 */
declare const ROOM_ORDER_CMD_ROBOT_V1 = "27";
/**
 * 定点清扫V1 App ➜ Robot
 */
declare const SPOT_CLEAN_CMD_APP_V1 = "16";
/**
 * 定点清扫V1 Robot ➜ App
 */
declare const SPOT_CLEAN_CMD_ROBOT_V1 = "17";
/**
 * 定点清扫V2 App ➜ Robot
 */
declare const SPOT_CLEAN_CMD_APP_V2 = "3e";
/**
 * 定点清扫V2 Robot ➜ App
 */
declare const SPOT_CLEAN_CMD_ROBOT_V2 = "3f";
/**
 * 分区分割V1 App ➜ Robot
 */
declare const PARTITION_DIVISION_CMD_APP_V1 = "1c";
/**
 * 分区分割V1 Robot ➜ App
 */
declare const PARTITION_DIVISION_CMD_ROBOT_V1 = "1d";
/**
 * 分区合并V1 App ➜ Robot
 */
declare const PARTITION_MERGE_CMD_APP_V1 = "1e";
/**
 * 分区合并V1 Robot ➜ App
 */
declare const PARTITION_MERGE_CMD_ROBOT_V1 = "1f";
/**
 * 设置房间属性V1 App ➜ Robot
 */
declare const SET_ROOM_PROPERTY_CMD_APP_V1 = "22";
/**
 * 设置房间属性V1 Robot ➜ App
 */
declare const SET_ROOM_PROPERTY_CMD_ROBOT_V1 = "23";
/**
 * 设置房间名称V1 App ➜ Robot
 */
declare const SET_ROOM_NAME_CMD_APP_V1 = "24";
/**
 * 设置房间名称V1 Robot ➜ App
 */
declare const SET_ROOM_NAME_CMD_ROBOT_V1 = "25";
/**
 * 划区清扫V1 App ➜ Robot
 */
declare const ZONE_CLEAN_CMD_APP_V1 = "28";
/**
 * 划区清扫V1 Robot ➜ App
 */
declare const ZONE_CLEAN_CMD_ROBOT_V1 = "29";
/**
 * 划区清扫V2 App ➜ Robot
 */
declare const ZONE_CLEAN_CMD_APP_V2 = "3a";
/**
 * 划区清扫V2 Robot ➜ App
 */
declare const ZONE_CLEAN_CMD_ROBOT_V2 = "3b";
/**
 * 勿扰时间设置V1 App ➜ Robot
 */
declare const DO_NOT_DISTURB_CMD_APP_V1 = "32";
/**
 * 勿扰时间设置V1 Robot ➜ App
 */
declare const DO_NOT_DISTURB_CMD_ROBOT_V1 = "33";
/**
 * 勿扰时间设置V2 App ➜ Robot
 */
declare const DO_NOT_DISTURB_CMD_APP_V2 = "40";
/**
 * 勿扰时间设置V2 Robot ➜ App
 */
declare const DO_NOT_DISTURB_CMD_ROBOT_V2 = "41";
/**
 * 本地定时设置 APP >> Robot
 */
declare const LOCAL_TIMER_CMD_APP_30 = "30";
/**
 * 本地定时设置 Robot >> APP
 */
declare const LOCAL_TIMER_CMD_ROBOT_31 = "31";
/**
 * 快速建图 App ➜ Robot
 */
declare const QUICK_MAP_CMD_APP_V1 = "3c";
/**
 * 快速建图 Robot ➜ App
 */
declare const QUICK_MAP_CMD_ROBOT_V1 = "3d";
/**
 * 重置地图 App ➜ Robot
 */
declare const RESET_MAP_CMD_APP_V1 = "42";
/**
 * 重置地图 Robot ➜ App
 */
declare const RESET_MAP_CMD_ROBOT_V1 = "43";
/**
 * 设置分区地板材质 App ➜ Robot
 */
declare const SET_FLOOR_MATERIAL_CMD_APP_V1 = "52";
/**
 * 设置分区地板材质 Robot ➜ App
 */
declare const SET_FLOOR_MATERIAL_CMD_ROBOT_V1 = "53";
/** -------------------------拓展功能--------------------------- */
/**
 * 拓展功能帧头
 */
declare const EXTEND_FEATURE_HEADER = "ab";
/**
 * 保存地图 App ➜ Robot
 */
declare const SAVE_MAP_CMD_APP_V1 = "2a";
/**
 * 保存地图 Robot ➜ App
 */
declare const SAVE_MAP_CMD_ROBOT_V1 = "2b";
/**
 * 删除地图 App ➜ Robot
 */
declare const DELETE_MAP_CMD_APP_V1 = "2c";
/**
 * 删除地图 Robot ➜ App
 */
declare const DELETE_MAP_CMD_ROBOT_V1 = "2d";
/**
 * 使用地图 App ➜ Robot
 */
declare const USE_MAP_CMD_APP_V1 = "2e";
/**
 * 使用地图 Robot ➜ App
 */
declare const USE_MAP_CMD_ROBOT_V1 = "2f";
/**
 * 语音包 App ➜ Robot
 */
declare const VOICE_APP_V1 = "34";
/**
 * 语音包 Robot ➜ App
 */
declare const VOICE_ROBOT_V1 = "35";
declare const FEATURE_DECODE_MAP: {
    readonly 13: "decodeVirtualWall0x13";
    readonly 49: "decodeVirtualWall0x49";
    readonly "1b": "decodeVirtualArea0x1b";
    readonly 39: "decodeVirtualArea0x39";
    readonly 15: "decodeRoomClean0x15";
    readonly 57: "decodeRoomClean0x57";
    readonly 17: "decodeSpotClean0x17";
    readonly "3f": "decodeSpotClean0x3f";
    readonly 29: "decodeZoneClean0x29";
    readonly "3b": "decodeZoneClean0x3b";
    readonly "1d": "decodePartitionDivision0x1d";
    readonly "1f": "decodePartitionMerge0x1f";
    readonly 23: "decodeSetRoomProperty0x23";
    readonly 25: "decodeSetRoomName0x25";
    readonly "2b": "decodeSaveMap0x2b";
    readonly "2d": "decodeDeleteMap0x2d";
    readonly "2f": "decodeUseMap0x2f";
    readonly 27: "decodeRoomOrder0x27";
    readonly 33: "decodeDoNotDisturb0x33";
    readonly 41: "decodeDoNotDisturb0x41";
    readonly "3d": "decodeQuickMap0x3d";
    readonly 43: "decodeResetMap0x43";
    readonly 31: "decodeDeviceTimer0x31";
    readonly 35: "decodeVoice0x35";
};

/**
 * 构建扫地机标准功能指令 App ➜ Robot
 * @param version 协议版本
 * @param cmd 命令字
 * @param data 数据
 * @returns 指令
 */
declare const encodeStandardFeatureCommand: (cmd: string, data: string, version: '0' | '1') => string;
/**
 * 构建扫地机拓展功能指令 App ➜ Robot
 * @param cmd 命令字
 * @param data 数据
 * @returns 指令
 */
declare const encodeExtendFeatureCommand: (cmd: string, data: string) => string;
/**
 * 从指令中解析得到必要信息
 * @param command 指令
 * @param cmd 命令字
 * @param version 协议版本
 * @returns 解析数据
 */
declare const decodeStandardFeatureCommand: (command: string, cmd: string, version?: '0' | '1') => {
    valid: boolean;
    dataLength?: number;
    cmdStr?: string;
    dataStr?: string;
};
/**
 * 从指令中解析指令协议版本
 * @param command 指令
 * @returns 协议版本
 */
declare const getFeatureProtocolVersion: (command: string) => '0' | '1';
/**
 * 从指令中获取命令字
 * @param command 指令
 * @param version 协议版本
 * @returns 命令字
 */
declare const getCmdStrFromStandardFeatureCommand: (command: string, version?: '0' | '1') => string;
/**
 * 将数据数组转化为数据指令
 *
 * 数组项接受
 *
 * 1. 对象类型(可配置不同字节)
 *
 * 2. 数值类型(1个字节的数据可以这么使用)
 *
 * 3. 字符串类型(直接传入byte字符串)
 * @param dataArray 数据数组
 * @returns 数据指令
 */
declare const convertDataArrayToDataStr: (dataArray: DataArray) => string;

/**
 * 点到直线的最短距离的判断 点（x0,y0） 到由两点组成的线段（x1,y1） ,( x2,y2 )
 */
declare const pointToLine: (x1: number, y1: number, x2: number, y2: number, x0: number, y0: number) => number;
/**
 * 判断两个区域是否相邻
 * @param list1
 * @param list2
 * @return
 */
declare const isAdjacent: (list1: Array<{
    x: number;
    y: number;
}>, list2: Array<{
    x: number;
    y: number;
}>, threshold?: number) => boolean;
/**
 * 判断两个区域是否接壤
 * @param points1
 * @param points2
 * @return
 */
declare const isBorder: (points1: Array<{
    x: number;
    y: number;
}>, points2: Array<{
    x: number;
    y: number;
}>) => boolean;
interface Circle extends Point {
    radius: number;
}
type Rect = [Point, Point, Point, Point];
/**
 * 判断圆是否与矩形相交
 *
 * @export
 * @param {Circle} circle
 * @param {Rect} rect
 * @returns {Boolean}
 */
declare const circleIntersectRect: (circle: Circle, rect: Rect) => boolean;

/**
 * 转换roomHexId到roomId
 * 需要根据协议版本进行转换
 * @param pixel
 * @version 地图版本
 */
declare const parseRoomId: (pixel: string, version?: 0 | 1 | 2) => number;
/**
 * 转换roomId到roomHexId
 * 需要根据协议版本进行转换
 * @param pixel
 * @version 地图版本
 */
declare const parseRoomHexId: (roomId: number, version?: 0 | 1 | 2) => string;
/**
 * 将十进制转为指定长度的十六进制字符串
 * @param num 十进制
 * @param padding 位数(默认为2)
 * @returns
 */
declare const numToHexString: (num: number, padding?: number) => string;
/**
 * 缩放相应的倍数
 * @param scale 倍数
 * @param value 被缩放的值
 * @returns
 */
declare const scaleNumber: (scale: number, value: number) => number;
/**
 * 兼容负数 byte 最大值平分给正负两端
 * @param point
 * @returns
 */
declare const dealPL: (point: number) => number;
/**
 * 高位加低位
 * @param high
 * @param low
 * @returns
 */
declare const highLowToInt: (high: any, low: any) => any;
/**
 * 缩放x, y轴
 * @param mapScale 倍数
 * @param x
 * @param y
 * @returns
 */
declare const transformXY: (mapScale: number, value: number) => number;
/**
 * 放大倍数
 * @param data 被放大的值
 * @param scale 倍数
 * @returns
 */
declare const dealScale: (data: number, scale: number) => number;
/**
 * 按照每个字节将16进制转换为10进制数字，并进行累加和操作
 * @param data 十六进制字符串
 * @returns
 */
declare const addHex: (data: string) => number;
/**
 * 字节转十六进制字符串
 * @param bytes
 * @returns
 */
declare const bytesToHexString: (bytes: number[]) => string;
/**
 * 十六进制字符串按照UTF8编码
 * @param hex
 * @returns
 */
declare const hexToUTF8: (hex: string) => string;
/**
 * 字符串转字节码
 * @param str
 * @returns
 */
declare const stringToByte: (str: string) => any[];
/**
 * 字节码转十六进制字符串
 * @param arr
 * @returns
 */
declare const bytes2Str: (arr: Array<number | string>) => string;
/**
 * 某些协议是一个定长字节的表示，当数据不足19字节的时候，需要进行的补0操作
 * @param str
 * @param len
 * @returns
 */
declare const hexPlusLen: (str: string, len: number) => string;
/**
 * 负数时区取反码
 * 返回十进制整数
 * @param num
 */
declare const completionTimeZone: (num: number) => number;
/**
 * 字符串转十六进制
 * @param str
 * @returns
 */
declare const stringToAtHex: (str: string) => string;
/**
 * 截取最后几位数的字符
 * @param {} v
 * @param {*} length
 */
declare const lastChar: (num: number, length?: number) => string;
declare const getHexXYFromXY: ({ x, y }: Point, origin: Point, mapScale?: number) => {
    hexX: string;
    hexY: string;
};
declare const hexStringToNumber: (hexString: string, byte?: number) => any[];
declare const transformChargeXY: ({ chargeX, chargeY, }: {
    chargeX: number;
    chargeY: number;
}, { originX, originY }: {
    originX: number;
    originY: number;
}) => {
    x: number;
    y: number;
};
/**
 * roomHex的组装
 */
declare const combineTwoBinaryToHex: (binary1: string, binary2: string) => string;
declare const convertColorToArgbHex: (color: string) => string;
declare const subStrToInt: (value: string, start: number, length?: number) => number;
declare const from16To2: (v: string, length?: number) => string;
declare const processHex: (inputHex: string) => string;
declare const makeXYArray: (hexStr?: string, mapScale?: number) => {
    x: number;
    y: number;
};
declare const arrayBufferToOctetStream: (arrayBuffer: ArrayBuffer) => string;

export { type AIPicHD, type AiPicInfo, BITMAP_TYPE_HEX_MAP, BITMAP_TYPE_MAP, BITMAP_TYPE_MAP_REFLECTION, BITMAP_TYPE_MAP_V2, type Cistern, type CleanMode, DEFAULT_HIGHLIGHT_MAP_COLOR, DEFAULT_NORMAL_MAP_COLOR, DELETE_MAP_CMD_APP_V1, DELETE_MAP_CMD_ROBOT_V1, DO_NOT_DISTURB_CMD_APP_V1, DO_NOT_DISTURB_CMD_APP_V2, DO_NOT_DISTURB_CMD_ROBOT_V1, DO_NOT_DISTURB_CMD_ROBOT_V2, type DataArray, EXTEND_FEATURE_HEADER, FEATURE_DECODE_MAP, type ForbiddenType, LOCAL_TIMER_CMD_APP_30, LOCAL_TIMER_CMD_ROBOT_31, type MapData, type MapHeader, PARTITION_DIVISION_CMD_APP_V1, PARTITION_DIVISION_CMD_ROBOT_V1, PARTITION_MERGE_CMD_APP_V1, PARTITION_MERGE_CMD_ROBOT_V1, PATH_HEADER_LENGTH, PATH_POINT_TYPE_MAP, POINT_HEX_TOTAL, type PathData, type PathHeader, type PathPoint, type PathPointType, type Point, QUICK_MAP_CMD_APP_V1, QUICK_MAP_CMD_ROBOT_V1, RESET_MAP_CMD_APP_V1, RESET_MAP_CMD_ROBOT_V1, ROOM_CLEAN_CMD_APP_V1, ROOM_CLEAN_CMD_APP_V2, ROOM_CLEAN_CMD_ROBOT_V1, ROOM_CLEAN_CMD_ROBOT_V2, ROOM_NAME_LENGTH, ROOM_ORDER_CMD_APP_V1, ROOM_ORDER_CMD_ROBOT_V1, ROOM_PROPERTY_LENGTH, ROOM_VERTICES_NUM_LENGTH, type RoomDecoded, SAVE_MAP_CMD_APP_V1, SAVE_MAP_CMD_ROBOT_V1, SET_FLOOR_MATERIAL_CMD_APP_V1, SET_FLOOR_MATERIAL_CMD_ROBOT_V1, SET_ROOM_NAME_CMD_APP_V1, SET_ROOM_NAME_CMD_ROBOT_V1, SET_ROOM_PROPERTY_CMD_APP_V1, SET_ROOM_PROPERTY_CMD_ROBOT_V1, SPOT_CLEAN_CMD_APP_V1, SPOT_CLEAN_CMD_APP_V2, SPOT_CLEAN_CMD_ROBOT_V1, SPOT_CLEAN_CMD_ROBOT_V2, STANDARD_FEATURE_HEADER, type ShapeType, type Suction, type TimerData, UNKNOWN_AREA_ID, UNKNOWN_AREA_ID_V2, USE_MAP_CMD_APP_V1, USE_MAP_CMD_ROBOT_V1, VIRTUAL_AREA_CMD_APP_V1, VIRTUAL_AREA_CMD_APP_V2, VIRTUAL_AREA_CMD_ROBOT_V1, VIRTUAL_AREA_CMD_ROBOT_V2, VIRTUAL_WALL_CMD_APP_V1, VIRTUAL_WALL_CMD_APP_V2, VIRTUAL_WALL_CMD_ROBOT_V1, VIRTUAL_WALL_CMD_ROBOT_V2, VOICE_APP_V1, VOICE_ROBOT_V1, type VirtualArea, type VirtualWall, ZONE_CLEAN_CMD_APP_V1, ZONE_CLEAN_CMD_APP_V2, ZONE_CLEAN_CMD_ROBOT_V1, ZONE_CLEAN_CMD_ROBOT_V2, type Zone, addHex, arrayBufferToOctetStream, bytes2Str, bytesToHexString, circleIntersectRect, combineTwoBinaryToHex, completionTimeZone, convertColorToArgbHex, convertDataArrayToDataStr, dealPL, dealScale, decodeAiPicData, decodeAiPicHDData, decodeDeleteMap0x2d, decodeDeleteMapV1, decodeDeviceTimer0x31, decodeDoNotDisturb0x33, decodeDoNotDisturb0x41, decodeDoNotDisturbV2, decodeMap, decodeMapData, decodeMapHeader, decodePartitionDivision0x1d, decodePartitionDivisionV1, decodePartitionMerge0x1f, decodePartitionMergeV1, decodePath, decodePathData, decodePathHeader, decodeRoomClean0x15, decodeRoomClean0x57, decodeRoomCleanV1, decodeRoomCleanV2, decodeRoomOrder0x27, decodeRoomOrderV1, decodeSaveMap0x2b, decodeSaveMapV1, decodeSetRoomFloorMaterial0x53, decodeSetRoomName0x25, decodeSetRoomNameV1, decodeSetRoomProperty0x23, decodeSetRoomPropertyV1, decodeSpotClean0x17, decodeSpotClean0x3f, decodeSpotCleanV1, decodeSpotCleanV2, decodeStandardFeatureCommand, decodeUseMap0x2f, decodeUseMapV1, decodeVirtualArea0x1b, decodeVirtualArea0x39, decodeVirtualAreaV2, decodeVirtualWall0x13, decodeVirtualWall0x49, decodeVirtualWallV1, decodeVoice0x35, decodeZoneClean0x29, decodeZoneClean0x3b, decodeZoneCleanV2, encodeDeleteMap0x2c, encodeDeleteMapV1, encodeDeviceTimer0x30, encodeDoNotDisturb0x32, encodeDoNotDisturb0x40, encodeDoNotDisturbV2, encodeExtendFeatureCommand, encodePartitionDivision0x1c, encodePartitionDivisionV1, encodePartitionMerge0x1e, encodePartitionMergeV1, encodeQuickMap0x3c, encodeQuickMapV1, encodeResetMap0x42, encodeResetMapV1, encodeRoomClean0x14, encodeRoomClean0x56, encodeRoomCleanV1, encodeRoomCleanV2, encodeRoomOrder0x26, encodeRoomOrderV1, encodeSaveMap0x2a, encodeSaveMapV1, encodeSetRoomFloorMaterial0x52, encodeSetRoomName0x24, encodeSetRoomNameV1, encodeSetRoomProperty0x22, encodeSetRoomPropertyV1, encodeSpotClean0x16, encodeSpotClean0x3e, encodeSpotCleanV1, encodeSpotCleanV2, encodeStandardFeatureCommand, encodeUseMap0x2e, encodeUseMapV1, encodeVirtualArea0x1a, encodeVirtualArea0x38, encodeVirtualAreaV2, encodeVirtualWall0x12, encodeVirtualWall0x48, encodeVirtualWallV1, encodeVoice0x34, encodeZoneClean0x28, encodeZoneClean0x3a, encodeZoneCleanV2, from16To2, getCmdStrFromStandardFeatureCommand, getFeatureProtocolVersion, getHexXYFromXY, getMapProtocolVersion, hexPlusLen, hexStringToNumber, hexToUTF8, highLowToInt, isAdjacent, isBorder, lastChar, makeXYArray, numToHexString, parseRoomHexId, parseRoomId, pointToLine, processHex, requestRoomClean0x15, requestRoomClean0x57, requestRoomCleanV1, requestRoomCleanV2, requestRoomOrder0x26, requestRoomOrderV1, requestSpotClean0x17, requestSpotClean0x3f, requestSpotCleanV1, requestSpotCleanV2, requestVirtualArea0x1b, requestVirtualArea0x39, requestVirtualAreaV2, requestVirtualWall0x13, requestVirtualWall0x49, requestVirtualWallV1, requestZoneClean0x29, requestZoneClean0x3b, requestZoneCleanV2, scaleNumber, stringToAtHex, stringToByte, subStrToInt, transformChargeXY, transformXY, type yMop };
